globalVariables(c("chrom", "start", "end", "strand",
                  ".exon_num", ".exon_size", ".exon_start",
                  "name", ".prev_end", "size",
                  "max.end", "size_mean", "int_est", ".starts", ".ends", ".row",
                  ".start", ".end", ".size", ".strand",
                  "start.x", "end.x", "strand.x",
                  "start.y", "strand.x", "strand.y",
                  ".overlap", ".id", ".value", ".win_num",
                  ".facet", ".id_merge", ".overlap_merge",
                  ".end.x", ".start.x", "CHROM", "POS", "REF",
                  ".counts", "exon_sizes",
                  ".absdist", ".ref_gap", ".ref_points",
                  "exon_starts", "key", "left_end", "left_start", "pos",
                  ".reldist", "right_end",
                  "right_start", ".total", "value",
                  ".midpoint", ".obs_counts", ".length",
                  ".reference_coverage", ".total_trials", ".exp_prob",
                  "p.value", ".win_size", ".row_id",
                  "cds_start", "cds_end", "score"))
